@@ -3,7 +3,7 @@ package HTML::TurboForm::Element;
 use warnings;
 use strict;
 use base qw/ Class::Accessor /;
-__PACKAGE__->mk_accessors( qw/ params submit wrapper pure default dbsearchfield dbdata dbop dbid dblabel ignore_dbix type id name label text value request options class left_class right_class row_class attributes table submit columns / );
+__PACKAGE__->mk_accessors( qw/ params submit wrapper pure default dbsearchfield dbdata dbop dbid dblabel ignore_dbix type id name label text value request options optionsnum class left_class limit right_class row_class attributes table submit columns / );
 
 sub new{
     my ($class, $request) = @_;
@@ -23,7 +23,7 @@ sub new{
        }
     }
 
-    if ($self->submit){        
+    if ($self->submit){
         @{$self->{modules}} = ('jquery/jquery');
         $self->{js} = ' $("#'.$self->name.'").'.$self->submit.'(function(){$("form")[0].submit(); });  ';
     }
@@ -114,7 +114,7 @@ sub vor{
 
     return "" if ( $self->pure );
     my $error='';
-    
+
     $error=$options->{error_message} if $options->{error_message};
     my $result='';
     my $table='';
@@ -131,10 +131,16 @@ sub vor{
 
     if ($self->{view} eq '') {
         $error="<div class='form_error'>$error</div>" if ($error ne '');
-
+        
+        $self->label('') if (!$self->label);
         $result=$table."<div ".$class.$rwc.">".$error.
                        "<div class='form_left'".$ltc.">".$self->label."</div>".
                        "<div class='form_right'".$rtc.">";
+		       
+#$result=$table."<div ".$class.$rwc.">".$error.
+#                       "<div class='form_left'".$ltc.">".$self->label."</div>".
+#                       "<div class='form_right'".$rtc.">";		       
+		       
         $result=$table."<div ".$class.$rwc.">" if ($self->type eq "Html");
     }
 
@@ -161,13 +167,16 @@ sub vor{
         $result.=$error.'<br />' if ($error ne '');
     }
 
-    if ($self->wrapper){		  
+    if ($self->wrapper){
 		my $wrap=$self->wrapper;
-		$wrap=~s/<label>/$self->label/g;
+		my $s='';
+		$s=$self->label if (!$s);		
+		$wrap=~s/<label>/$s/g;		
+		$wrap=~s/<error>//g if (!$error);
 		$wrap=~s/<error>/$error/g if ($error ne '');
 		my $pos=index($wrap,'<element>');
 		$result=substr($wrap,0,$pos);
-		$self->{after_wrap}=$result=substr($wrap,$pos+10);
+		$self->{after_wrap}=substr($wrap,$pos+9);
 	}
 
     return $result;
@@ -179,19 +188,26 @@ sub nach{
     return "" if ($self->pure );
     my $result= "</div></div>";
     my $table='';
+	$result='' if ($self->wrapper);
 
     $result="</div>" if ($self->type eq "Html");
     $result="</td></tr>"  if ($self->{view} eq 'table');
     $result="</td>"  if ($self->{view} eq 'column');
-	
+
 	if ($self->wrapper){
 		$result=$self->{after_wrap} if ($self->{after_wrap});
 	}
-
     $result.="\n";
     return $result;
 }
 
+sub get_label{
+    my ($self) = @_;
+    my $result='';
+    $result=$self->label if $self->label;
+    return $result;
+}
+
 sub get_value{
     my ($self) = @_;
     my $result='';
@@ -261,4 +277,3 @@ return given posthtml
 Thorsten Domsch, tdomsch@gmx.de
 
 =cut
-
